@@ -10,7 +10,7 @@ from oort.server.errors import (
     InvalidOrganisationTelescopeOortCloudError,
     InvalidWatchOptionsOortCloudError
 )
-from tests.utils import (TEST_LOGIN_API_KEY, TEST_LOGIN_ORG_ROLE, TEST_LOGIN_ORG_SUBDOMAIN, TEST_LOGIN_USERNAME,
+from tests.utils import (TEST_LOGIN_UPLOAD_KEY, TEST_LOGIN_ORG_ROLE, TEST_LOGIN_ORG_SUBDOMAIN, TEST_LOGIN_USERNAME,
                          save_test_credentials, use_test_database)
 
 TELESCOPE_UUID = str(uuid.uuid4())
@@ -31,12 +31,12 @@ def test_cli_folders_no_options_org_nor_telescope():
 
     # Perform: Empty arguments everywhere
     o, organisation, t, telescope, astronomer = None, None, None, None, (None, None)
-    username, api_key, org_subdomain, org_role, telescope_details = \
+    username, upload_key, org_subdomain, org_role, telescope_details = \
         parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
     # Assert
     assert username == TEST_LOGIN_USERNAME
-    assert api_key == TEST_LOGIN_API_KEY
+    assert upload_key == TEST_LOGIN_UPLOAD_KEY
     assert org_subdomain == ''
     assert org_role == ''
     assert telescope_details is None
@@ -54,7 +54,7 @@ def test_cli_folders_with_options_org_but_no_telescope():
         with pytest.raises(InvalidOrgMembershipOortCloudError):
             # Perform: Empty arguments everywhere except organisation
             o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, None, None, (None, None)
-            username, api_key, org_subdomain, org_role, telescope_details = \
+            username, upload_key, org_subdomain, org_role, telescope_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_method_read.call_count == 1
@@ -73,7 +73,7 @@ def test_cli_folders_with_options_org_and_telescope():
             # Perform: Empty arguments everywhere except organisation
             o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, TELESCOPE_UUID, None, (
                 None, None)
-            username, api_key, org_subdomain, org_role, telescope_details = \
+            username, upload_key, org_subdomain, org_role, telescope_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_method_read.call_count == 1
@@ -90,13 +90,13 @@ def test_cli_folders_with_options_telescope_as_t():
     with patch.object(ArcsecondAPI, 'read', return_value=(TELESCOPE_DETAILS, None)) as mock_method_read:
         # Perform
         o, organisation, t, telescope, astronomer = None, None, TELESCOPE_UUID, None, (None, None)
-        username, api_key, org_subdomain, org_role, telescope_details = \
+        username, upload_key, org_subdomain, org_role, telescope_details = \
             parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         # Assert
         assert mock_method_read.call_count == 1
         assert username == TEST_LOGIN_USERNAME
-        assert api_key == TEST_LOGIN_API_KEY
+        assert upload_key == TEST_LOGIN_UPLOAD_KEY
         assert org_subdomain == ''
         assert org_role == ''
         assert telescope_details == TELESCOPE_DETAILS
@@ -112,13 +112,13 @@ def test_cli_folders_with_options_telescope_as_telescope():
 
     with patch.object(ArcsecondAPI, 'read', return_value=(TELESCOPE_DETAILS, None)) as mock_method_read:
         o, organisation, t, telescope, astronomer = None, None, None, TELESCOPE_UUID, (None, None)
-        username, api_key, org_subdomain, org_role, telescope_details = \
+        username, upload_key, org_subdomain, org_role, telescope_details = \
             parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         # Assert
         assert mock_method_read.call_count == 1
         assert username == TEST_LOGIN_USERNAME
-        assert api_key == TEST_LOGIN_API_KEY
+        assert upload_key == TEST_LOGIN_UPLOAD_KEY
         assert org_subdomain == ''
         assert org_role == ''
         assert telescope_details == TELESCOPE_DETAILS
@@ -136,7 +136,7 @@ def test_cli_folders_with_options_telescope_but_invalid_telescope():
         with pytest.raises(InvalidOrganisationTelescopeOortCloudError):
             # The value of TELESCOPE_UUID has no importance, as method is patched.
             o, organisation, t, telescope, astronomer = None, None, None, TELESCOPE_UUID, (None, None)
-            username, api_key, org_subdomain, org_role, telescope_details = \
+            username, upload_key, org_subdomain, org_role, telescope_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_method_read.call_count == 1
@@ -150,7 +150,7 @@ def test_cli_folders_with_options_custom_astronomer_but_no_org_nor_telescope():
             patch.object(ArcsecondAPI, 'read', return_value=(CUSTOM_ASTRONOMER_DETAILS, None)) as mock_method_read:
         with pytest.raises(InvalidWatchOptionsOortCloudError):
             o, organisation, t, telescope, astronomer = None, None, None, None, CUSTOM_ASTRONOMER
-            username, api_key, org_subdomain, org_role, telescope_details = \
+            username, upload_key, org_subdomain, org_role, telescope_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_method_me.call_count == 1
@@ -165,7 +165,7 @@ def test_cli_folders_with_options_custom_astronomer_with_org_but_no_telescope():
             patch.object(ArcsecondAPI, 'read', return_value=(CUSTOM_ASTRONOMER_DETAILS, None)) as mock_method_read:
         with pytest.raises(InvalidOrgMembershipOortCloudError):
             o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, None, None, CUSTOM_ASTRONOMER
-            username, api_key, org_subdomain, org_role, telescope_details = \
+            username, upload_key, org_subdomain, org_role, telescope_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_method_me.call_count == 0
@@ -180,7 +180,7 @@ def test_cli_folders_with_options_custom_astronomer_with_org_and_telescope():
             patch.object(ArcsecondAPI, 'read', return_value=(CUSTOM_ASTRONOMER_DETAILS, None)) as mock_method_read:
         with pytest.raises(InvalidOrgMembershipOortCloudError):
             o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, TELESCOPE_UUID, None, CUSTOM_ASTRONOMER
-            username, api_key, org_subdomain, org_role, telescope_details = \
+            username, upload_key, org_subdomain, org_role, telescope_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_method_me.call_count == 0
